@@ -99,6 +99,8 @@ class DSLibraryViaMMLibrary(DSLibrary):
             return write_stream_with_read_on_close(w_mode=mode, r_mode='rb', on_close=finalize)
         # for read we fully load the data and make a stream
         if "r" in mode:
+            # ignore path - resources have 'simple' names
+            path = path.split("/")[-1]
             try:
                 reader = self._find_method("get_binary_from_resource", "getBinaryFromResource")
                 if mode == 'rb':
