@@ -267,7 +267,7 @@ def db_conn_flavor(connector) -> str:
     """
     Determine connector flavor.
     """
-    if hasattr(connector, "_flavor"):
+    if hasattr(connector, "_flavor") and connector._flavor:
         return connector._flavor
     name = connector.__class__.__name__.lower()
     if "postg" in name or "psycopg" in name:
